Browse Source

Stefan Fiedler:


			
			
				rocklinux
			
			
		
Stefan Fiedler 19 years ago
parent
commit
ac132f4d52
2 changed files with 90 additions and 0 deletions
  1. +54
    -0
      package/base/glibc/glibc23/arm-ctl_bus_isa.patch
  2. +36
    -0
      package/base/glibc/glibc23/double-defined-symbols.patch.cross.arm

+ 54
- 0
package/base/glibc/glibc23/arm-ctl_bus_isa.patch

@ -0,0 +1,54 @@
copied from the crosstool project (0.38) - see http://kegel.com/crosstool/
- stf
Applies to both glibc-2.2.5 and glibc-2.3.2, and probably glibc cvs as of Aug 2004.
Needed to build glibc with linux kernels 2.4.23 or higher on ARM,
Fixes following error:
../sysdeps/unix/sysv/linux/arm/ioperm.c: In function `init_iosys':
../sysdeps/unix/sysv/linux/arm/ioperm.c:103: error: `BUS_ISA' undeclared (first use in this function)
../sysdeps/unix/sysv/linux/arm/ioperm.c:103: error: (Each undeclared identifier is reported only once
../sysdeps/unix/sysv/linux/arm/ioperm.c:103: error: for each function it appears in.)
../sysdeps/unix/sysv/linux/arm/ioperm.c:103: error: initializer element is not constant
../sysdeps/unix/sysv/linux/arm/ioperm.c:103: error: (near initialization for `iobase_name[1]')
../sysdeps/unix/sysv/linux/arm/ioperm.c:104: error: initializer element is not constant
../sysdeps/unix/sysv/linux/arm/ioperm.c:104: error: (near initialization for `ioshift_name[1]')
make[2]: *** [/home/dank/crosstool-0.28/build/arm-softfloat-linux-gnu/gcc-3.3.4-glibc-2.2.5/build-glibc/misc/ioperm.o] Error 1
cf. "[SYSCTL] BUS_ISA -> CTL_BUS_ISA", http://www.ussg.iu.edu/hypermail/linux/kernel/0311.0/0529.html
--- glibc-2.3.6/sysdeps/unix/sysv/linux/bind.S~ 2002-05-15 02:17:25.000000000 +0200
+++ glibc-2.3.6/sysdeps/unix/sysv/linux/bind.S 2006-02-05 21:15:36.000000000 +0100
@@ -2,4 +2,3 @@
#define NARGS 3
#define NO_WEAK_ALIAS 1
#include <socket.S>
-weak_alias (bind, __bind)
--- glibc-2.3.6/sysdeps/unix/sysv/linux/getsockname.S~ 2002-05-15 02:17:58.000000000 +0200
+++ glibc-2.3.6/sysdeps/unix/sysv/linux/getsockname.S 2006-02-05 21:21:31.000000000 +0100
@@ -2,4 +2,3 @@
#define NARGS 3
#define NO_WEAK_ALIAS 1
#include <socket.S>
-weak_alias (getsockname, __getsockname)
--- glibc-2.3.6/sysdeps/unix/sysv/linux/listen.S~ 2002-05-15 02:18:37.000000000 +0200
+++ glibc-2.3.6/sysdeps/unix/sysv/linux/listen.S 2006-02-05 21:27:54.000000000 +0100
@@ -2,4 +2,3 @@
#define NARGS 2
#define NO_WEAK_ALIAS 1
#include <socket.S>
-weak_alias (listen, __listen)
--- glibc-2.3.6/sysdeps/unix/sysv/linux/setsockopt.S~ 2002-05-15 02:19:09.000000000 +0200
+++ glibc-2.3.6/sysdeps/unix/sysv/linux/setsockopt.S 2006-02-05 21:31:42.000000000 +0100
@@ -2,4 +2,3 @@
#define NARGS 5
#define NO_WEAK_ALIAS 1
#include <socket.S>
-weak_alias (setsockopt, __setsockopt)

Loading…
Cancel
Save
--- glibc-2.3.2/sysdeps/unix/sysv/linux/arm/ioperm.c.old 2003-02-20 14:22:24.000000000 -0800
+++ glibc-2.3.2/sysdeps/unix/sysv/linux/arm/ioperm.c 2004-01-31 16:01:50.000000000 -0800
@@ -47,6 +47,12 @@
#include <asm/page.h>
#include <sys/sysctl.h>
+/* see http://www.ussg.iu.edu/hypermail/linux/kernel/0311.0/0529.html */
+#include <linux/version.h>
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,4,23))
+#define CTL_BUS_ISA BUS_ISA /* and hope it's not the one from linux/input.h */
+#endif
+
#define PATH_ARM_SYSTYPE "/etc/arm_systype"
#define PATH_CPUINFO "/proc/cpuinfo"
@@ -80,7 +86,7 @@
* Initialize I/O system. There are several ways to get the information
* we need. Each is tried in turn until one succeeds.
*
* 1. Sysctl (CTL_BUS, BUS_ISA, ISA_*). This is the preferred method
* but not all kernels support it.
*
* 2. Read the value (not the contents) of symlink PATH_ARM_SYSTYPE.
@@ -100,8 +106,8 @@
{
char systype[256];
int i, n;
- static int iobase_name[] = { CTL_BUS, BUS_ISA, BUS_ISA_PORT_BASE };
- static int ioshift_name[] = { CTL_BUS, BUS_ISA, BUS_ISA_PORT_SHIFT };
+ static int iobase_name[] = { CTL_BUS, CTL_BUS_ISA, BUS_ISA_PORT_BASE };
+ static int ioshift_name[] = { CTL_BUS, CTL_BUS_ISA, BUS_ISA_PORT_SHIFT };
size_t len = sizeof(io.base);
if (! sysctl (iobase_name, 3, &io.io_base, &len, NULL, 0)

+ 36
- 0
package/base/glibc/glibc23/double-defined-symbols.patch.cross.arm

@ -0,0 +1,36 @@
fixes errors like:
../sysdeps/unix/sysv/linux/listen.S: Assembler messages:
../sysdeps/unix/sysv/linux/listen.S:5: Error: symbol `__listen' is already defined
@@ -80,7 +86,7 @@
* we need. Each is tried in turn until one succeeds.
*
- * 1. Sysctl (CTL_BUS, BUS_ISA, ISA_*). This is the preferred method
+ * 1. Sysctl (CTL_BUS, CTL_BUS_ISA, ISA_*). This is the preferred method
* but not all kernels support it.
*
make[2]: *** [/usr/src/ROCK-TRUNK/src.glibc23.1139165527.2121.4182052479/glibc-2.3.6/objdir/socket/listen.o] Error 1
make[2]: Leaving directory `/usr/src/ROCK-TRUNK/src.glibc23.1139165527.2121.4182052479/glibc-2.3.6/socket'
make[1]: *** [socket/subdir_lib] Error 2